@@ -34,4 +34,7 @@ pub enum VerifierError {
 
 	#[error("No ids were extracted from the main entity endpoint")]
 	NoIds,
+
+	#[error("{0} argument is not a URL")]
+	ArgNotURL(&'static str),
 }
