@@ -1,18 +1,9 @@
-use std::collections::{BTreeMap, HashMap};
+use std::collections::BTreeMap;
 use std::path::PathBuf;
 
 use serde::{Deserialize, Serialize};
 use url::Url;
 
-use crate::output::EndpointOutput;
-
-#[derive(Debug, Clone, Serialize, Deserialize)]
-pub struct BeaconOutput {
-	pub name: String,
-	pub url: Url,
-	pub entities: BTreeMap<String, Vec<EndpointOutput>>,
-}
-
 #[derive(Debug, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Endpoint {
@@ -21,7 +12,7 @@ pub struct Endpoint {
 	pub root_url: Url,
 	pub single_entry_url: Option<Url>,
 	pub filtering_terms_url: Option<Url>,
-	pub endpoints: Option<HashMap<String, RelatedEndpoint>>,
+	pub endpoints: Option<BTreeMap<String, RelatedEndpoint>>,
 }
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
